[![Build Status](https://travis-ci.org/emcek/pyerge.svg?branch=master)](https://travis-ci.org/emcek/pyerge)
[![Coverage Status](https://coveralls.io/repos/github/emcek/pyerge/badge.svg?branch=master)](https://coveralls.io/github/emcek/pyerge?branch=master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/2f60c2eb170f4158a5df3880ea8ca836)](https://app.codacy.com/app/mplichta/pyerge?utm_source=github.com&utm_medium=referral&utm_content=emcek/pyerge&utm_campaign=Badge_Grade_Dashboard)
[![BCH compliance](https://bettercodehub.com/edge/badge/emcek/pyerge?branch=master)](https://bettercodehub.com/)
[![License](https://img.shields.io/badge/Licence-GPL--2-blue.svg)](./LICENSE)

# pyerge

Various tools to emerge and to show status for conky
